==> IPC-Concurrency-DBI-1.1.2.tar.gz: IPC-Concurrency-DBI-1.1.2/README.md <==
IPC-Concurrency-DBI
===================

[![Build Status](https://travis-ci.org/guillaumeaubert/IPC-Concurrency-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/IPC-Concurrency-DBI)

IPC::Concurrency::DBI controls how many instances of a given application are
allowed to run in parallel, using DBI as the IPC method.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc IPC::Concurrency::DBI


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/IPC-Concurrency-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/IPC-Concurrency-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/IPC-Concurrency-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/IPC-Concurrency-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2011-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> IPC-Concurrency-DBI-v1.1.3.tar.gz: IPC-Concurrency-DBI-v1.1.3/README.md <==
IPC-Concurrency-DBI
===================

[![Build Status](https://travis-ci.org/guillaumeaubert/IPC-Concurrency-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/IPC-Concurrency-DBI)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/IPC-Concurrency-DBI/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/IPC-Concurrency-DBI?branch=master)

IPC::Concurrency::DBI controls how many instances of a given application are
allowed to run in parallel, using DBI as the IPC method.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc IPC::Concurrency::DBI


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/IPC-Concurrency-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/IPC-Concurrency-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/IPC-Concurrency-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/IPC-Concurrency-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2011-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
